@@ -1,8 +1,8 @@
 from .builder import fields
 from .client import Client
-from .proxy import QueryServiceProxy, MutationServiceProxy
+from .proxy import QueryServiceProxy, MutationServiceProxy, SubscriptionServiceProxy
 from .schema import Schema
 from .settings import Settings
 from .transport import Transporter, AsyncTransporter
 
-__version__ = "1.1.1"
+__version__ = "1.1.2"
